@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_certificatemanager._jsii
 import aws_cdk.aws_cloudfront._jsii
@@ -19,7 +19,7 @@ import aws_cdk.aws_s3_deployment._jsii
 import aws_cdk.core._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-spa-deploy", "1.56.0", __name__[0:-6], "cdk-spa-deploy@1.56.0.jsii.tgz"
+    "cdk-spa-deploy", "1.67.0", __name__[0:-6], "cdk-spa-deploy@1.67.0.jsii.tgz"
 )
 
 __all__ = [
